import { Component, Input, Output, EventEmitter, ViewEncapsulation, ViewChild, HostListener, ContentChild, ChangeDetectionStrategy, NgModule } from '@angular/core';
import { BaseChartComponent, LineSeriesComponent, calculateViewDimensions, ColorHelper, formatLabel, NgxChartsModule } from '@swimlane/ngx-charts';
import { curveLinear, curveBundle } from 'd3-shape';
import { scaleBand, scaleLinear, scalePoint, scaleTime } from 'd3-scale';
import { trigger, style, animate, transition } from '@angular/animations';
import { CommonModule } from '@angular/common';
import { NgxGraphModule } from '@swimlane/ngx-graph';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class NeuChartsComponent {
    constructor() { }
    /**
     * @return {?}
     */
    ngOnInit() { }
}
NeuChartsComponent.decorators = [
    { type: Component, args: [{
                selector: 'neu-charts',
                template: `<h3>Neu-charts works!</h3>
`,
                styles: [``]
            },] },
];
/** @nocollapse */
NeuChartsComponent.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Options for charts
 * @author Prasanth Venkatesan
 */
class Options {
    /**
     * @param {?=} showLegend
     */
    constructor(showLegend = true) {
        this.showLegend = showLegend;
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Pie chart options
 * @author Prasanth Venkatesan
 */
class PieOptions extends Options {
    /**
     * @param {?=} showLegend
     * @param {?=} showLabels
     * @param {?=} explodeSlices
     */
    constructor(showLegend = true, showLabels = true, explodeSlices = false) {
        super(showLegend);
        this.showLabels = showLabels;
        this.explodeSlices = explodeSlices;
        this.doughnut = false;
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
let customColorSets = [
    {
        name: 'palatte',
        domain: ['#9896F8', '#55efc4', '#76B3F9', '#81DD98', '#b867d3', '#f26f96', '#ffeaa7', '#FDBD2D', '#FC8A25', '#4d488c', '#FA4F1E', '#BDC3C7']
    }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Pie chart component
 * @author Prasanth Venkatesan
 */
class PieChartComponent {
    constructor() {
        this.data = [];
        this.onSelect = new EventEmitter();
        this.options = new PieOptions();
        this.colorScheme = customColorSets.find(s => s.name == 'palatte');
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        Object.assign(this.options, this.customOptions);
    }
    /**
     * @param {?} event
     * @return {?}
     */
    mSelectedEvent(event) {
        this.onSelect.emit(event);
    }
}
PieChartComponent.decorators = [
    { type: Component, args: [{
                selector: 'neu-charts-pie',
                template: `<div class="chart-container" *ngIf="data && (data.length > 0)">
    <ngx-charts-pie-chart
        [scheme]="colorScheme"
        [results]="data"
        [legend]="options.showLegend"
        [explodeSlices]="options.explodeSlices"
        [labels]="options.showLabels"
        [doughnut]="options.doughnut"
        [gradient]="gradient"
        (select)="mSelectedEvent($event)">
        </ngx-charts-pie-chart>
</div>
<no-data *ngIf="(!data) || (data.length <= 0)"></no-data>`,
                styles: [`.chart-container{width:100%;height:100%}`]
            },] },
];
/** @nocollapse */
PieChartComponent.ctorParameters = () => [];
PieChartComponent.propDecorators = {
    "data": [{ type: Input, args: ['data',] },],
    "customOptions": [{ type: Input, args: ['options',] },],
    "onSelect": [{ type: Output },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Donut options model
 * @author Prasanth Venkatesan
 */
class DonutOptions extends PieOptions {
    /**
     * @param {?=} showLegend
     * @param {?=} showLabels
     * @param {?=} arcWidth
     */
    constructor(showLegend = true, showLabels = true, arcWidth = 0.3) {
        super(showLegend, showLabels, false);
        this.doughnut = true;
        this.arcWidth = arcWidth;
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Donut chart component
 * @author Prasanth Venkatesan
 */
class DonutChartComponent {
    constructor() {
        this.data = [];
        this.onSelect = new EventEmitter();
        this.options = new DonutOptions();
        this.colorScheme = customColorSets.find(s => s.name == 'palatte');
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        Object.assign(this.options, this.cutomOptions);
    }
    /**
     * @param {?} event
     * @return {?}
     */
    mSelectedEvent(event) {
        this.onSelect.emit(event);
    }
}
DonutChartComponent.decorators = [
    { type: Component, args: [{
                selector: 'neu-charts-donut',
                template: `<div class="chart-container" *ngIf="data && (data.length > 0)">
    <ngx-charts-pie-chart
        [scheme]="colorScheme"
        [results]="data"
        [legend]="options.showLegend"
        [explodeSlices]="options.explodeSlices"
        [labels]="options.showLabels"
        [doughnut]="options.doughnut"
        [arcWidth]="options.arcWidth"
        [gradient]="gradient"
        (select)="mSelectedEvent($event)">
        </ngx-charts-pie-chart>
</div>
<no-data *ngIf="(!data) || (data.length <= 0)"></no-data>`,
                styles: [`.chart-container{width:100%;height:100%}`]
            },] },
];
/** @nocollapse */
DonutChartComponent.ctorParameters = () => [];
DonutChartComponent.propDecorators = {
    "data": [{ type: Input, args: ['data',] },],
    "cutomOptions": [{ type: Input, args: ['options',] },],
    "onSelect": [{ type: Output },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * No data or wrong data format component
 * @author Prasanth Venkatesan
 */
class NoDataComponent {
    constructor() { }
    /**
     * @return {?}
     */
    ngOnInit() { }
}
NoDataComponent.decorators = [
    { type: Component, args: [{
                selector: 'no-data',
                template: `<div class="no-data-container">No data found (or) Wrong data format</div>`,
                styles: [`
    .no-data-container {
        width: 100%;
        height: 100%;
        display: flex;
        justify-content: center;
        align-items: center;
        color: lightslategray;
        font-size: 1.2rem;
    }`]
            },] },
];
/** @nocollapse */
NoDataComponent.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Advanced donut component
 * @author Prasanth Venkatesan
 */
class DonutAdvancedComponent {
    constructor() {
        this.data = [];
        this.onSelect = new EventEmitter();
        this.colorScheme = customColorSets.find(s => s.name == 'palatte');
    }
    /**
     * @return {?}
     */
    ngOnInit() { }
    /**
     * @param {?} event
     * @return {?}
     */
    mSelectedEvent(event) {
        this.onSelect.emit(event);
    }
}
DonutAdvancedComponent.decorators = [
    { type: Component, args: [{
                selector: 'neu-charts-donut-advanced',
                template: `<div class="chart-container" *ngIf="data && (data.length > 0)">
    <ngx-charts-advanced-pie-chart
        [view]="view"
        [scheme]="colorScheme"
        [results]="data"
        [gradient]="gradient"
        (select)="mSelectedEvent($event)">
        </ngx-charts-advanced-pie-chart>
</div>
<no-data *ngIf="(!data) || (data.length <= 0)"></no-data>`,
                styles: [`.chart-container{width:100%;height:100%}.chart-container /deep/ .total-value{font-size:1.4rem}.chart-container /deep/ .total-label{font-size:1.2rem}.chart-container /deep/ .legend-items{padding-top:10px}.chart-container /deep/ .legend-items .legend-item{line-height:1.4}.chart-container /deep/ .legend-items .legend-item:hover{opacity:.75}.chart-container /deep/ .legend-items .legend-item .item-value{font-size:1.2rem!important}.chart-container /deep/ .legend-items .legend-item .item-percent{font-size:1.1rem!important}`]
            },] },
];
/** @nocollapse */
DonutAdvancedComponent.ctorParameters = () => [];
DonutAdvancedComponent.propDecorators = {
    "data": [{ type: Input, args: ['data',] },],
    "onSelect": [{ type: Output },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class DonutGridComponent {
    constructor() {
        this.data = [];
        this.onSelect = new EventEmitter();
        this.colorScheme = customColorSets.find(s => s.name == 'palatte');
    }
    /**
     * @return {?}
     */
    ngOnInit() { }
    /**
     * @param {?} event
     * @return {?}
     */
    mSelectedEvent(event) {
        this.onSelect.emit(event);
    }
}
DonutGridComponent.decorators = [
    { type: Component, args: [{
                selector: 'neu-charts-donut-grid',
                template: `<div class="chart-container" *ngIf="data && (data.length > 0)">
    <ngx-charts-pie-grid
      [view]="view"
      [scheme]="colorScheme"
      [results]="data"
      (select)="mSelectedEvent($event)">
    </ngx-charts-pie-grid>
</div>
<no-data *ngIf="(!data) || (data.length <= 0)"></no-data>`,
                styles: [`.chart-container{width:100%;height:100%}`]
            },] },
];
/** @nocollapse */
DonutGridComponent.ctorParameters = () => [];
DonutGridComponent.propDecorators = {
    "data": [{ type: Input, args: ['data',] },],
    "onSelect": [{ type: Output },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Bar Options for charts
 * @author Prasanth Venkatesan
 */
class BarOptions extends Options {
    /**
     * @param {?=} showLegend
     * @param {?=} showXAxis
     * @param {?=} showYAxis
     * @param {?=} showXAxisLabel
     * @param {?=} showYAxisLabel
     * @param {?=} xAxisLabel
     * @param {?=} yAxisLabel
     */
    constructor(showLegend = true, showXAxis = true, showYAxis = true, showXAxisLabel = true, showYAxisLabel = true, xAxisLabel = '', yAxisLabel = '') {
        super(showLegend);
        this.showXAxis = showXAxis;
        this.showYAxis = showYAxis;
        this.showXAxisLabel = showXAxisLabel;
        this.showYAxisLabel = showYAxisLabel;
        this.xAxisLabel = xAxisLabel.toUpperCase();
        this.yAxisLabel = yAxisLabel.toUpperCase();
        this.barPadding = 3;
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Bar vertical chart
 * @author Prasanth Venkatesan
 */
class BarVerticalComponent {
    constructor() {
        this.onSelect = new EventEmitter();
        this.options = new BarOptions();
        this.colorScheme = customColorSets.find(s => s.name == 'palatte');
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        Object.assign(this.options, this.customOptions);
    }
    /**
     * @param {?} event
     * @return {?}
     */
    mSelectedEvent(event) {
        this.onSelect.emit(event);
    }
}
BarVerticalComponent.decorators = [
    { type: Component, args: [{
                selector: 'neu-charts-bar-vertical',
                template: `<div class="chart-container" *ngIf="data && (data.length > 0)">
    <ngx-charts-bar-vertical
      [scheme]="colorScheme"
      [results]="data"
      [gradient]="gradient"
      [xAxis]="options.showXAxis"
      [yAxis]="options.showYAxis"
      [legend]="options.showLegend"
      [showXAxisLabel]="options.showXAxisLabel"
      [showYAxisLabel]="options.showYAxisLabel"
      [xAxisLabel]="options.xAxisLabel"
      [yAxisLabel]="options.yAxisLabel"
      [barPadding]="options.barPadding"
      (select)="mSelectedEvent($event)">
    </ngx-charts-bar-vertical>
</div>
<no-data *ngIf="(!data) || (data.length <= 0)"></no-data>`,
                styles: [`.chart-container{width:100%;height:100%}`]
            },] },
];
/** @nocollapse */
BarVerticalComponent.ctorParameters = () => [];
BarVerticalComponent.propDecorators = {
    "data": [{ type: Input, args: ['data',] },],
    "customOptions": [{ type: Input, args: ['options',] },],
    "onSelect": [{ type: Output },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Bar horizontal chart
 * @author Prasanth Venkatesan
 */
class BarHorizontalComponent {
    constructor() {
        this.onSelect = new EventEmitter();
        this.options = new BarOptions();
        this.colorScheme = customColorSets.find(s => s.name == 'palatte');
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        Object.assign(this.options, this.customOptions);
    }
    /**
     * @param {?} event
     * @return {?}
     */
    mSelectedEvent(event) {
        this.onSelect.emit(event);
    }
}
BarHorizontalComponent.decorators = [
    { type: Component, args: [{
                selector: 'neu-charts-bar-horizontal',
                template: `<div class="chart-container" *ngIf="data && (data.length > 0)">
    <ngx-charts-bar-horizontal
      [scheme]="colorScheme"
      [results]="data"
      [gradient]="gradient"
      [xAxis]="options.showXAxis"
      [yAxis]="options.showYAxis"
      [legend]="options.showLegend"
      [showXAxisLabel]="options.showXAxisLabel"
      [showYAxisLabel]="options.showYAxisLabel"
      [xAxisLabel]="options.xAxisLabel"
      [yAxisLabel]="options.yAxisLabel"
      [barPadding]="options.barPadding"
      (select)="mSelectedEvent($event)">
    </ngx-charts-bar-horizontal>
</div>
<no-data *ngIf="(!data) || (data.length <= 0)"></no-data>`,
                styles: [`.chart-container{width:100%;height:100%}`]
            },] },
];
/** @nocollapse */
BarHorizontalComponent.ctorParameters = () => [];
BarHorizontalComponent.propDecorators = {
    "data": [{ type: Input, args: ['data',] },],
    "customOptions": [{ type: Input, args: ['options',] },],
    "onSelect": [{ type: Output },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Bar grouped Options for charts
 * @author Prasanth Venkatesan
 */
class BarGroupedOptions extends BarOptions {
    /**
     * @param {?=} showLegend
     * @param {?=} showXAxis
     * @param {?=} showYAxis
     * @param {?=} showXAxisLabel
     * @param {?=} showYAxisLabel
     * @param {?=} xAxisLabel
     * @param {?=} yAxisLabel
     */
    constructor(showLegend = true, showXAxis = true, showYAxis = true, showXAxisLabel = true, showYAxisLabel = true, xAxisLabel = '', yAxisLabel = '') {
        super(showLegend, showXAxis, showYAxis, showXAxisLabel, showYAxisLabel, xAxisLabel, yAxisLabel);
        this.groupPadding = 6;
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Bar vertical grouped chart
 * @author Prasanth Venkatesan
 */
class BarVerticalGroupedComponent {
    constructor() {
        this.onSelect = new EventEmitter();
        this.options = new BarGroupedOptions();
        this.colorScheme = customColorSets.find(s => s.name == 'palatte');
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        Object.assign(this.options, this.customOptions);
    }
    /**
     * @param {?} event
     * @return {?}
     */
    mSelectedEvent(event) {
        this.onSelect.emit(event);
    }
}
BarVerticalGroupedComponent.decorators = [
    { type: Component, args: [{
                selector: 'neu-charts-bar-vertical-grouped',
                template: `<div class="chart-container" *ngIf="data && (data.length > 0)">
    <ngx-charts-bar-vertical-2d
      [scheme]="colorScheme"
      [results]="data"
      [gradient]="gradient"
      [xAxis]="options.showXAxis"
      [yAxis]="options.showYAxis"
      [legend]="options.showLegend"
      [showXAxisLabel]="options.showXAxisLabel"
      [showYAxisLabel]="options.showYAxisLabel"
      [xAxisLabel]="options.xAxisLabel"
      [yAxisLabel]="options.yAxisLabel"
      [barPadding]="options.barPadding"
      [groupPadding]="options.groupPadding"
      (select)="mSelectedEvent($event)">
    </ngx-charts-bar-vertical-2d>
</div>
<no-data *ngIf="(!data) || (data.length <= 0)"></no-data>`,
                styles: [`.chart-container{width:100%;height:100%}`]
            },] },
];
/** @nocollapse */
BarVerticalGroupedComponent.ctorParameters = () => [];
BarVerticalGroupedComponent.propDecorators = {
    "data": [{ type: Input, args: ['data',] },],
    "customOptions": [{ type: Input, args: ['options',] },],
    "onSelect": [{ type: Output },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Bar horizontal grouped chart
 * @author Prasanth Venkatesan
 */
class BarHorizontalGroupedComponent {
    constructor() {
        this.onSelect = new EventEmitter();
        this.options = new BarGroupedOptions();
        this.colorScheme = customColorSets.find(s => s.name == 'palatte');
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        Object.assign(this.options, this.customOptions);
    }
    /**
     * @param {?} event
     * @return {?}
     */
    mSelectedEvent(event) {
        this.onSelect.emit(event);
    }
}
BarHorizontalGroupedComponent.decorators = [
    { type: Component, args: [{
                selector: 'neu-charts-bar-horizontal-grouped',
                template: `<div class="chart-container" *ngIf="data && (data.length > 0)">
    <ngx-charts-bar-horizontal-2d
      [scheme]="colorScheme"
      [results]="data"
      [gradient]="gradient"
      [xAxis]="options.showXAxis"
      [yAxis]="options.showYAxis"
      [legend]="options.showLegend"
      [showXAxisLabel]="options.showXAxisLabel"
      [showYAxisLabel]="options.showYAxisLabel"
      [xAxisLabel]="options.xAxisLabel"
      [yAxisLabel]="options.yAxisLabel"
      [barPadding]="options.barPadding"
      [groupPadding]="options.groupPadding"
      (select)="mSelectedEvent($event)">
    </ngx-charts-bar-horizontal-2d>
</div>
<no-data *ngIf="(!data) || (data.length <= 0)"></no-data>`,
                styles: [`.chart-container{width:100%;height:100%}`]
            },] },
];
/** @nocollapse */
BarHorizontalGroupedComponent.ctorParameters = () => [];
BarHorizontalGroupedComponent.propDecorators = {
    "data": [{ type: Input, args: ['data',] },],
    "customOptions": [{ type: Input, args: ['options',] },],
    "onSelect": [{ type: Output },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Bar horizontal stacked chart
 * @author Prasanth Venkatesan
 */
class BarHorizontalStackedComponent {
    constructor() {
        this.onSelect = new EventEmitter();
        this.options = new BarOptions();
        this.colorScheme = customColorSets.find(s => s.name == 'palatte');
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        Object.assign(this.options, this.customOptions);
    }
    /**
     * @param {?} event
     * @return {?}
     */
    mSelectedEvent(event) {
        this.onSelect.emit(event);
    }
}
BarHorizontalStackedComponent.decorators = [
    { type: Component, args: [{
                selector: 'neu-charts-bar-horizontal-stacked',
                template: `<div class="chart-container" *ngIf="data && (data.length > 0)">
    <ngx-charts-bar-horizontal-stacked
      [scheme]="colorScheme"
      [results]="data"
      [gradient]="gradient"
      [xAxis]="options.showXAxis"
      [yAxis]="options.showYAxis"
      [legend]="options.showLegend"
      [showXAxisLabel]="options.showXAxisLabel"
      [showYAxisLabel]="options.showYAxisLabel"
      [xAxisLabel]="options.xAxisLabel"
      [yAxisLabel]="options.yAxisLabel"
      [barPadding]="options.barPadding"
      (select)="mSelectedEvent($event)">
    </ngx-charts-bar-horizontal-stacked>
</div>
<no-data *ngIf="(!data) || (data.length <= 0)"></no-data>`,
                styles: [`.chart-container{width:100%;height:100%}`]
            },] },
];
/** @nocollapse */
BarHorizontalStackedComponent.ctorParameters = () => [];
BarHorizontalStackedComponent.propDecorators = {
    "data": [{ type: Input, args: ['data',] },],
    "customOptions": [{ type: Input, args: ['options',] },],
    "onSelect": [{ type: Output },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Bar vertical stacked chart
 * @author Prasanth Venkatesan
 */
class BarVerticalStackedComponent {
    constructor() {
        this.onSelect = new EventEmitter();
        this.options = new BarOptions();
        this.colorScheme = customColorSets.find(s => s.name == 'palatte');
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        Object.assign(this.options, this.customOptions);
    }
    /**
     * @param {?} event
     * @return {?}
     */
    mSelectedEvent(event) {
        this.onSelect.emit(event);
    }
}
BarVerticalStackedComponent.decorators = [
    { type: Component, args: [{
                selector: 'neu-charts-bar-vertical-stacked',
                template: `<div class="chart-container" *ngIf="data && (data.length > 0)">
    <ngx-charts-bar-vertical-stacked
      [scheme]="colorScheme"
      [results]="data"
      [gradient]="gradient"
      [xAxis]="options.showXAxis"
      [yAxis]="options.showYAxis"
      [legend]="options.showLegend"
      [showXAxisLabel]="options.showXAxisLabel"
      [showYAxisLabel]="options.showYAxisLabel"
      [xAxisLabel]="options.xAxisLabel"
      [yAxisLabel]="options.yAxisLabel"
      [barPadding]="options.barPadding"
      (select)="mSelectedEvent($event)">
    </ngx-charts-bar-vertical-stacked>
</div>
<no-data *ngIf="(!data) || (data.length <= 0)"></no-data>`,
                styles: [`.chart-container{width:100%;height:100%}`]
            },] },
];
/** @nocollapse */
BarVerticalStackedComponent.ctorParameters = () => [];
BarVerticalStackedComponent.propDecorators = {
    "data": [{ type: Input, args: ['data',] },],
    "customOptions": [{ type: Input, args: ['options',] },],
    "onSelect": [{ type: Output },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Bar vertical normalized chart
 * @author Prasanth Venkatesan
 */
class BarVerticalNormalizedComponent {
    constructor() {
        this.onSelect = new EventEmitter();
        this.options = new BarOptions();
        this.colorScheme = customColorSets.find(s => s.name == 'palatte');
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        Object.assign(this.options, this.customOptions);
    }
    /**
     * @param {?} event
     * @return {?}
     */
    mSelectedEvent(event) {
        this.onSelect.emit(event);
    }
}
BarVerticalNormalizedComponent.decorators = [
    { type: Component, args: [{
                selector: 'neu-charts-bar-vertical-normalized',
                template: `<div class="chart-container" *ngIf="data && (data.length > 0)">
    <ngx-charts-bar-vertical-normalized
      [scheme]="colorScheme"
      [results]="data"
      [gradient]="gradient"
      [xAxis]="options.showXAxis"
      [yAxis]="options.showYAxis"
      [legend]="options.showLegend"
      [showXAxisLabel]="options.showXAxisLabel"
      [showYAxisLabel]="options.showYAxisLabel"
      [xAxisLabel]="options.xAxisLabel"
      [yAxisLabel]="options.yAxisLabel"
      [barPadding]="options.barPadding"
      (select)="mSelectedEvent($event)">
    </ngx-charts-bar-vertical-normalized>
</div>
<no-data *ngIf="(!data) || (data.length <= 0)"></no-data>`,
                styles: [`.chart-container{width:100%;height:100%}`]
            },] },
];
/** @nocollapse */
BarVerticalNormalizedComponent.ctorParameters = () => [];
BarVerticalNormalizedComponent.propDecorators = {
    "data": [{ type: Input, args: ['data',] },],
    "customOptions": [{ type: Input, args: ['options',] },],
    "onSelect": [{ type: Output },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Bar horizontal normalized chart
 * @author Prasanth Venkatesan
 */
class BarHorizontalNormalizedComponent {
    constructor() {
        this.onSelect = new EventEmitter();
        this.options = new BarOptions();
        this.colorScheme = customColorSets.find(s => s.name == 'palatte');
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        Object.assign(this.options, this.customOptions);
    }
    /**
     * @param {?} event
     * @return {?}
     */
    mSelectedEvent(event) {
        this.onSelect.emit(event);
    }
}
BarHorizontalNormalizedComponent.decorators = [
    { type: Component, args: [{
                selector: 'neu-charts-bar-horizontal-normalized',
                template: `<div class="chart-container" *ngIf="data && (data.length > 0)">
    <ngx-charts-bar-horizontal-normalized
      [scheme]="colorScheme"
      [results]="data"
      [gradient]="gradient"
      [xAxis]="options.showXAxis"
      [yAxis]="options.showYAxis"
      [legend]="options.showLegend"
      [showXAxisLabel]="options.showXAxisLabel"
      [showYAxisLabel]="options.showYAxisLabel"
      [xAxisLabel]="options.xAxisLabel"
      [yAxisLabel]="options.yAxisLabel"
      [barPadding]="options.barPadding"
      (select)="mSelectedEvent($event)">
    </ngx-charts-bar-horizontal-normalized>
</div>
<no-data *ngIf="(!data) || (data.length <= 0)"></no-data>`,
                styles: [`.chart-container{width:100%;height:100%}`]
            },] },
];
/** @nocollapse */
BarHorizontalNormalizedComponent.ctorParameters = () => [];
BarHorizontalNormalizedComponent.propDecorators = {
    "data": [{ type: Input, args: ['data',] },],
    "customOptions": [{ type: Input, args: ['options',] },],
    "onSelect": [{ type: Output },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Line Options for charts
 * @author Prasanth Venkatesan
 */
class LineOptions extends BarOptions {
    /**
     * @param {?=} showLegend
     * @param {?=} showXAxis
     * @param {?=} showYAxis
     * @param {?=} showXAxisLabel
     * @param {?=} showYAxisLabel
     * @param {?=} xAxisLabel
     * @param {?=} yAxisLabel
     * @param {?=} timeline
     * @param {?=} isXAxisDate
     * @param {?=} referenceLines
     */
    constructor(showLegend = true, showXAxis = true, showYAxis = true, showXAxisLabel = true, showYAxisLabel = true, xAxisLabel = '', yAxisLabel = '', timeline = false, isXAxisDate = false, referenceLines = []) {
        super(showLegend, showXAxis, showYAxis, showXAxisLabel, showYAxisLabel, xAxisLabel, yAxisLabel);
        this.autoScale = true;
        this.roundDomains = true;
        this.timeline = timeline;
        this.isXAxisDate = isXAxisDate;
        if (referenceLines.length == 0) {
            this.showRefLines = true;
        }
        this.referenceLines = referenceLines;
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class LineComponent {
    constructor() {
        this.onSelect = new EventEmitter();
        this.options = new LineOptions();
        this.colorScheme = customColorSets.find(s => s.name == 'palatte');
    }
    /**
     * @return {?}
     */
    ngOnInit() { }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        Object.assign(this.options, this.customOptions);
        if ((this.data && (changes["data"].previousValue != changes["data"].currentValue)) ||
            (this.options.isXAxisDate && (changes["customOptions"].previousValue != changes["customOptions"].currentValue))) {
            this.data.forEach(element => {
                element.series.forEach(seriesData => {
                    seriesData.name = new Date(seriesData.name);
                });
            });
        }
    }
    /**
     * @param {?} event
     * @return {?}
     */
    mSelectedEvent(event) {
        this.onSelect.emit(event);
    }
}
LineComponent.decorators = [
    { type: Component, args: [{
                selector: 'neu-charts-line',
                template: `<div class="chart-container" *ngIf="data && (data.length > 0)">
    <ngx-charts-line-chart
        [scheme]="colorScheme"
        [results]="data"
        [legend]="options.showLegend"
        [xAxis]="options.showXAxis"
        [yAxis]="options.showYAxis"
        [showXAxisLabel]="options.showXAxisLabel"
        [showYAxisLabel]="options.showYAxisLabel"
        [xAxisLabel]="options.xAxisLabel"
        [yAxisLabel]="options.yAxisLabel"
        [autoScale]="options.autoScale"
        [roundDomains]="options.roundDomains"
        [timeline]="options.timeline"
        (select)="mSelectedEvent($event)"
        [showRefLines]="options.showRefLines"
        [referenceLines]="options.referenceLines">
    </ngx-charts-line-chart>
</div>
<no-data *ngIf="(!data) || (data.length <= 0)"></no-data>`,
                styles: [`.chart-container{width:100%;height:100%}`]
            },] },
];
/** @nocollapse */
LineComponent.ctorParameters = () => [];
LineComponent.propDecorators = {
    "data": [{ type: Input, args: ['data',] },],
    "customOptions": [{ type: Input, args: ['options',] },],
    "onSelect": [{ type: Output },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Area chart component
 * @author Prasanth Venkatesan
 */
class AreaComponent {
    constructor() {
        this.onSelect = new EventEmitter();
        this.options = new LineOptions();
        this.colorScheme = customColorSets.find(s => s.name == 'palatte');
    }
    /**
     * @return {?}
     */
    ngOnInit() { }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        Object.assign(this.options, this.customOptions);
        if ((this.data && (changes["data"].previousValue != changes["data"].currentValue)) ||
            (this.options.isXAxisDate && (changes["customOptions"].previousValue != changes["customOptions"].currentValue))) {
            this.data.forEach(element => {
                element.series.forEach(seriesData => {
                    seriesData.name = new Date(seriesData.name);
                });
            });
        }
    }
    /**
     * @param {?} event
     * @return {?}
     */
    mSelectedEvent(event) {
        this.onSelect.emit(event);
    }
}
AreaComponent.decorators = [
    { type: Component, args: [{
                selector: 'neu-charts-area',
                template: `<div class="chart-container" *ngIf="data && (data.length > 0)">
    <ngx-charts-area-chart
        [scheme]="colorScheme"
        [results]="data"
        [legend]="options.showLegend"
        [xAxis]="options.showXAxis"
        [yAxis]="options.showYAxis"
        [showXAxisLabel]="options.showXAxisLabel"
        [showYAxisLabel]="options.showYAxisLabel"
        [xAxisLabel]="options.xAxisLabel"
        [yAxisLabel]="options.yAxisLabel"
        [autoScale]="options.autoScale"
        [timeline]="options.timeline"
        (select)="mSelectedEvent($event)">
        <!-- [roundDomains]="options.roundDomains"> -->
    </ngx-charts-area-chart>
</div>
<no-data *ngIf="(!data) || (data.length <= 0)"></no-data>`,
                styles: [`.chart-container{width:100%;height:100%}`]
            },] },
];
/** @nocollapse */
AreaComponent.ctorParameters = () => [];
AreaComponent.propDecorators = {
    "data": [{ type: Input, args: ['data',] },],
    "customOptions": [{ type: Input, args: ['options',] },],
    "onSelect": [{ type: Output },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Area stacked chart component
 * @author Prasanth Venkatesan
 */
class AreaStackedComponent {
    constructor() {
        this.onSelect = new EventEmitter();
        this.options = new LineOptions();
        this.colorScheme = customColorSets.find(s => s.name == 'palatte');
    }
    /**
     * @return {?}
     */
    ngOnInit() { }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        Object.assign(this.options, this.customOptions);
        if ((this.data && (changes["data"].previousValue != changes["data"].currentValue)) ||
            (this.options.isXAxisDate && (changes["customOptions"].previousValue != changes["customOptions"].currentValue))) {
            this.data.forEach(element => {
                element.series.forEach(seriesData => {
                    seriesData.name = new Date(seriesData.name);
                });
            });
        }
    }
    /**
     * @param {?} event
     * @return {?}
     */
    mSelectedEvent(event) {
        this.onSelect.emit(event);
    }
}
AreaStackedComponent.decorators = [
    { type: Component, args: [{
                selector: 'neu-charts-area-stacked',
                template: `<div class="chart-container" *ngIf="data && (data.length > 0)">
    <ngx-charts-area-chart-stacked
        [scheme]="colorScheme"
        [results]="data"
        [legend]="options.showLegend"
        [xAxis]="options.showXAxis"
        [yAxis]="options.showYAxis"
        [showXAxisLabel]="options.showXAxisLabel"
        [showYAxisLabel]="options.showYAxisLabel"
        [xAxisLabel]="options.xAxisLabel"
        [yAxisLabel]="options.yAxisLabel"
        [timeline]="options.timeline"
        (select)="mSelectedEvent($event)">
        <!-- [autoScale]="options.autoScale"
        [roundDomains]="options.roundDomains"> -->
    </ngx-charts-area-chart-stacked>
</div>
<no-data *ngIf="(!data) || (data.length <= 0)"></no-data>`,
                styles: [`.chart-container{width:100%;height:100%}`]
            },] },
];
/** @nocollapse */
AreaStackedComponent.ctorParameters = () => [];
AreaStackedComponent.propDecorators = {
    "data": [{ type: Input, args: ['data',] },],
    "customOptions": [{ type: Input, args: ['options',] },],
    "onSelect": [{ type: Output },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Area normalized chart component
 * @author Prasanth Venkatesan
 */
class AreaNormalizedComponent {
    constructor() {
        this.onSelect = new EventEmitter();
        this.options = new LineOptions();
        this.colorScheme = customColorSets.find(s => s.name == 'palatte');
    }
    /**
     * @return {?}
     */
    ngOnInit() { }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        Object.assign(this.options, this.customOptions);
        if ((this.data && (changes["data"].previousValue != changes["data"].currentValue)) ||
            (this.options.isXAxisDate && (changes["customOptions"].previousValue != changes["customOptions"].currentValue))) {
            this.data.forEach(element => {
                element.series.forEach(seriesData => {
                    seriesData.name = new Date(seriesData.name);
                });
            });
        }
    }
    /**
     * @param {?} event
     * @return {?}
     */
    mSelectedEvent(event) {
        this.onSelect.emit(event);
    }
}
AreaNormalizedComponent.decorators = [
    { type: Component, args: [{
                selector: 'neu-charts-area-normalized',
                template: `<div class="chart-container" *ngIf="data && (data.length > 0)">
    <ngx-charts-area-chart-normalized
        [scheme]="colorScheme"
        [results]="data"
        [legend]="options.showLegend"
        [xAxis]="options.showXAxis"
        [yAxis]="options.showYAxis"
        [showXAxisLabel]="options.showXAxisLabel"
        [showYAxisLabel]="options.showYAxisLabel"
        [xAxisLabel]="options.xAxisLabel"
        [yAxisLabel]="options.yAxisLabel"
        [timeline]="options.timeline"
        (select)="mSelectedEvent($event)">
        <!-- [autoScale]="options.autoScale"
        [roundDomains]="options.roundDomains"> -->
    </ngx-charts-area-chart-normalized>
</div>
<no-data *ngIf="(!data) || (data.length <= 0)"></no-data>`,
                styles: [`.chart-container{width:100%;height:100%}`]
            },] },
];
/** @nocollapse */
AreaNormalizedComponent.ctorParameters = () => [];
AreaNormalizedComponent.propDecorators = {
    "data": [{ type: Input, args: ['data',] },],
    "customOptions": [{ type: Input, args: ['options',] },],
    "onSelect": [{ type: Output },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Map Options for charts
 * @author Prasanth Venkatesan
 */
class MapOptions extends BarOptions {
    /**
     * @param {?=} showLegend
     * @param {?=} showXAxis
     * @param {?=} showYAxis
     * @param {?=} showXAxisLabel
     * @param {?=} showYAxisLabel
     * @param {?=} xAxisLabel
     * @param {?=} yAxisLabel
     * @param {?=} timeline
     * @param {?=} isXAxisDate
     * @param {?=} innerPadding
     * @param {?=} showSkew
     * @param {?=} colorScheme
     */
    constructor(showLegend = true, showXAxis = true, showYAxis = true, showXAxisLabel = true, showYAxisLabel = true, xAxisLabel = '', yAxisLabel = '', timeline = false, isXAxisDate = false, innerPadding = 5, showSkew = false, colorScheme = null) {
        super(showLegend, showXAxis, showYAxis, showXAxisLabel, showYAxisLabel, xAxisLabel, yAxisLabel);
        this.innerPadding = innerPadding;
        this.showSkew = showSkew;
        this.colorScheme = colorScheme;
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class HeatComponent {
    constructor() {
        this.onSelect = new EventEmitter();
        this.options = new MapOptions();
    }
    /**
     * @return {?}
     */
    ngOnInit() { }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        Object.assign(this.options, this.customOptions);
        if (this.options.colorScheme != null) {
            this.colorScheme = {};
            this.colorScheme['domain'] = this.options.colorScheme;
        }
        else {
            this.colorScheme = customColorSets.find(s => s.name == 'palatte');
        }
        if (this.options.showSkew && (changes["customOptions"].previousValue != changes["customOptions"].currentValue)) {
            this.data.sort((current, next) => {
                if (current.series.length > next.series.length) {
                    return -1;
                }
                else if (current.series.length < next.series.length) {
                    return 1;
                }
                return 0;
            });
        }
    }
    /**
     * @param {?} event
     * @return {?}
     */
    mSelectedEvent(event) {
        this.onSelect.emit(event);
    }
}
HeatComponent.decorators = [
    { type: Component, args: [{
                selector: 'neu-charts-heat',
                template: `<div class="chart-container" *ngIf="data && (data.length > 0)">
    <ngx-charts-heat-map
        [scheme]="colorScheme"
        [results]="data"
        [legend]="options.showLegend"
        [gradient]="gradient"
        [xAxis]="options.showXAxis"
        [yAxis]="options.showYAxis"
        [showXAxisLabel]="options.showXAxisLabel"
        [showYAxisLabel]="options.showYAxisLabel"
        [xAxisLabel]="options.xAxisLabel"
        [yAxisLabel]="options.yAxisLabel"
        [innerPadding]="options.innerPadding"
        (select)="mSelectedEvent($event)">
    </ngx-charts-heat-map>
</div>
<no-data *ngIf="(!data) || (data.length <= 0)"></no-data>`,
                styles: [``]
            },] },
];
/** @nocollapse */
HeatComponent.ctorParameters = () => [];
HeatComponent.propDecorators = {
    "data": [{ type: Input, args: ['data',] },],
    "customOptions": [{ type: Input, args: ['options',] },],
    "onSelect": [{ type: Output },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class TreeComponent {
    constructor() {
        this.onSelect = new EventEmitter();
        this.colorScheme = customColorSets.find(s => s.name == 'palatte');
    }
    /**
     * @return {?}
     */
    ngOnInit() { }
    /**
     * @param {?} event
     * @return {?}
     */
    mSelectedEvent(event) {
        this.onSelect.emit(event);
    }
}
TreeComponent.decorators = [
    { type: Component, args: [{
                selector: 'neu-charts-tree',
                template: `<div class="chart-container" *ngIf="data && (data.length > 0)">
    <ngx-charts-tree-map
        [scheme]="colorScheme"
        [results]="data"
        (select)="mSelectedEvent($event)">
    </ngx-charts-tree-map>
</div>
<no-data *ngIf="(!data) || (data.length <= 0)"></no-data>`,
                styles: [``]
            },] },
];
/** @nocollapse */
TreeComponent.ctorParameters = () => [];
TreeComponent.propDecorators = {
    "data": [{ type: Input, args: ['data',] },],
    "onSelect": [{ type: Output },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Bar line combo chart component
 * @author Prasanth Venkatesan
 */
class BarLineComboOptions extends BarOptions {
    /**
     * @param {?=} showLegend
     * @param {?=} showXAxis
     * @param {?=} showYAxis
     * @param {?=} showXAxisLabel
     * @param {?=} showYAxisLabel
     * @param {?=} xAxisLabel
     * @param {?=} yAxisLabel
     */
    constructor(showLegend = true, showXAxis = true, showYAxis = true, showXAxisLabel = true, showYAxisLabel = true, xAxisLabel = '', yAxisLabel = '') {
        super(showLegend, showXAxis, showYAxis, showXAxisLabel, showYAxisLabel, xAxisLabel, yAxisLabel);
        this.showRightYAxisLabel = false;
        // this.yAxisLabelRight = 'custom';
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class BarLineWrapperComponent {
    constructor() {
        this.dataBar = [];
        this.dataLine = [];
        this.onSelect = new EventEmitter();
        this.options = new BarLineComboOptions();
        this.colorScheme = customColorSets.find(s => s.name == 'palatte');
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        console.log(this.dataBar, this.dataLine);
        Object.assign(this.options, this.customOptions);
    }
    /**
     * @param {?} event
     * @return {?}
     */
    mSelectedEvent(event) {
        this.onSelect.emit(event);
    }
    /**
     * @param {?} min
     * @param {?} max
     * @return {?}
     */
    yLeftAxisScale(min, max) {
        return { min: `${min}`, max: `${max}` };
    }
    /**
     * @param {?} min
     * @param {?} max
     * @return {?}
     */
    yRightAxisScale(min, max) {
        return { min: `${min}`, max: `${max}` };
    }
    /**
     * @param {?} data
     * @return {?}
     */
    yLeftTickFormat(data) {
        return `${data.toLocaleString()}`;
    }
    /**
     * @param {?} data
     * @return {?}
     */
    yRightTickFormat(data) {
        return `${data}%`;
    }
}
BarLineWrapperComponent.decorators = [
    { type: Component, args: [{
                selector: 'neu-charts-combo-bar-line',
                template: `
<div class="chart-container" *ngIf="(dataBar && (dataBar.length > 0)) && (dataLine && (dataLine.length > 0))">
    <neu-charts-combo-bar-line-raw
        [scheme]="colorScheme"
        [colorSchemeLine]="lineChartScheme"
        [results]="dataBar"
        [lineChart]="dataLine"
        [legend]="options.showLegend"
        [xAxis]="options.showXAxis"
        [yAxis]="options.showYAxis"
        [showXAxisLabel]="options.showXAxisLabel"
        [showYAxisLabel]="options.showYAxisLabel"
        [xAxisLabel]="options.xAxisLabel"
        [yAxisLabel]="options.yAxisLabel"
        [showRightYAxisLabel]="options.showRightYAxisLabel"
        [yAxisLabelRight]="options.yAxisLabelRight"
        [yLeftAxisScaleFactor]="yLeftAxisScale"
        [yRightAxisScaleFactor]="yRightAxisScale"
        [yAxisTickFormatting]="yLeftTickFormat"
        [yRightAxisTickFormatting]="yRightTickFormat"
        (select)="mSelectedEvent($event)">
        </neu-charts-combo-bar-line-raw>
</div>
<no-data *ngIf="(!dataBar) || (dataBar.length <= 0) || (!dataLine) || (dataLine.length <= 0)"></no-data>`
            },] },
];
/** @nocollapse */
BarLineWrapperComponent.ctorParameters = () => [];
BarLineWrapperComponent.propDecorators = {
    "dataBar": [{ type: Input, args: ['dataBar',] },],
    "dataLine": [{ type: Input, args: ['dataLine',] },],
    "customOptions": [{ type: Input, args: ['options',] },],
    "onSelect": [{ type: Output },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class BarLineComponent extends BaseChartComponent {
    constructor() {
        super(...arguments);
        this.curve = curveLinear;
        this.legend = false;
        this.legendTitle = 'Legend';
        this.tooltipDisabled = false;
        this.showGridLines = true;
        this.activeEntries = [];
        this.schemeType = 'ordinal';
        this.roundDomains = false;
        this.animations = true;
        // @Output() select = new EventEmitter();
        this.activate = new EventEmitter();
        this.deactivate = new EventEmitter();
        this.margin = [10, 20, 10, 20];
        this.xAxisHeight = 0;
        this.yAxisWidth = 0;
        this.scaleType = 'linear';
        this.yOrientLeft = 'left';
        this.yOrientRight = 'right';
        this.legendSpacing = 0;
        this.barPadding = 8;
    }
    /**
     * @param {?} index
     * @param {?} item
     * @return {?}
     */
    trackBy(index, item) {
        return item.name;
    }
    /**
     * @return {?}
     */
    update() {
        super.update();
        this.dims = calculateViewDimensions({
            width: this.width,
            height: this.height,
            margins: this.margin,
            showXAxis: this.xAxis,
            showYAxis: this.yAxis,
            xAxisHeight: this.xAxisHeight,
            yAxisWidth: this.yAxisWidth,
            showXLabel: this.showXAxisLabel,
            showYLabel: this.showYAxisLabel,
            showLegend: this.legend,
            legendType: this.schemeType
        });
        if (!this.yAxis) {
            this.legendSpacing = 0;
        }
        else if (this.showYAxisLabel && this.yAxis) {
            this.legendSpacing = 100;
        }
        else {
            this.legendSpacing = 40;
        }
        this.xScale = this.getXScale();
        this.yScale = this.getYScale();
        // line chart
        this.xDomainLine = this.getXDomainLine();
        if (this.filteredDomain) {
            this.xDomainLine = this.filteredDomain;
        }
        this.yDomainLine = this.getYDomainLine();
        this.seriesDomain = this.getSeriesDomain();
        this.xScaleLine = this.getXScaleLine(this.xDomainLine, this.dims.width);
        this.yScaleLine = this.getYScaleLine(this.yDomainLine, this.dims.height);
        this.setColors();
        this.legendOptions = this.getLegendOptions();
        this.transform = `translate(${this.dims.xOffset} , ${this.margin[0]})`;
    }
    /**
     * @return {?}
     */
    deactivateAll() {
        this.activeEntries = [...this.activeEntries];
        for (const /** @type {?} */ entry of this.activeEntries) {
            this.deactivate.emit({ value: entry, entries: [] });
        }
        this.activeEntries = [];
    }
    /**
     * @return {?}
     */
    hideCircles() {
        this.hoveredVertical = null;
        this.deactivateAll();
    }
    /**
     * @param {?} item
     * @return {?}
     */
    updateHoveredVertical(item) {
        this.hoveredVertical = item.value;
        this.deactivateAll();
    }
    /**
     * @param {?} domain
     * @return {?}
     */
    updateDomain(domain) {
        this.filteredDomain = domain;
        this.xDomainLine = this.filteredDomain;
        this.xScaleLine = this.getXScaleLine(this.xDomainLine, this.dims.width);
    }
    /**
     * @return {?}
     */
    getSeriesDomain() {
        this.combinedSeries = this.lineChart.slice(0);
        this.combinedSeries.push({
            name: this.yAxisLabel,
            series: this.results
        });
        return this.combinedSeries.map(d => d.name);
    }
    /**
     * @param {?} value
     * @return {?}
     */
    isDate(value) {
        if (value instanceof Date) {
            return true;
        }
        return false;
    }
    /**
     * @param {?} values
     * @return {?}
     */
    getScaleType(values) {
        let /** @type {?} */ date = true;
        let /** @type {?} */ num = true;
        for (const /** @type {?} */ value of values) {
            if (!this.isDate(value)) {
                date = false;
            }
            if (typeof value !== 'number') {
                num = false;
            }
        }
        if (date)
            return 'time';
        if (num)
            return 'linear';
        return 'ordinal';
    }
    /**
     * @return {?}
     */
    getXDomainLine() {
        let /** @type {?} */ values = [];
        for (const /** @type {?} */ results of this.lineChart) {
            for (const /** @type {?} */ d of results.series) {
                if (values.indexOf(d.name) == -1) {
                    values.push(d.name);
                }
            }
        }
        this.scaleType = this.getScaleType(values);
        let /** @type {?} */ domain = [];
        if (this.scaleType === 'time') {
            const /** @type {?} */ min = Math.min(...values);
            const /** @type {?} */ max = Math.max(...values);
            domain = [min, max];
        }
        else if (this.scaleType === 'linear') {
            values = values.map(v => Number(v));
            const /** @type {?} */ min = Math.min(...values);
            const /** @type {?} */ max = Math.max(...values);
            domain = [min, max];
        }
        else {
            domain = values;
        }
        this.xSet = values;
        return domain;
    }
    /**
     * @return {?}
     */
    getYDomainLine() {
        const /** @type {?} */ domain = [];
        for (const /** @type {?} */ results of this.lineChart) {
            for (const /** @type {?} */ d of results.series) {
                if (domain.indexOf(d.value) < 0) {
                    domain.push(d.value);
                }
                if (d.min !== undefined) {
                    if (domain.indexOf(d.min) < 0) {
                        domain.push(d.min);
                    }
                }
                if (d.max !== undefined) {
                    if (domain.indexOf(d.max) < 0) {
                        domain.push(d.max);
                    }
                }
            }
        }
        let /** @type {?} */ min = Math.min(...domain);
        const /** @type {?} */ max = Math.max(...domain);
        if (this.yRightAxisScaleFactor) {
            const /** @type {?} */ minMax = this.yRightAxisScaleFactor(min, max);
            return [Math.min(0, minMax.min), minMax.max];
        }
        else {
            min = Math.min(0, min);
            return [min, max];
        }
    }
    /**
     * @param {?} domain
     * @param {?} width
     * @return {?}
     */
    getXScaleLine(domain, width) {
        let /** @type {?} */ scale;
        if (this.bandwidth === undefined) {
            this.bandwidth = (this.dims.width - this.barPadding);
        }
        if (this.scaleType === 'time') {
            scale = scaleTime()
                .range([0, width])
                .domain(domain);
        }
        else if (this.scaleType === 'linear') {
            scale = scaleLinear()
                .range([0, width])
                .domain(domain);
            if (this.roundDomains) {
                scale = scale.nice();
            }
        }
        else if (this.scaleType === 'ordinal') {
            scale = scalePoint()
                .range([this.bandwidth / 2, width - this.bandwidth / 2])
                .domain(domain);
        }
        return scale;
    }
    /**
     * @param {?} domain
     * @param {?} height
     * @return {?}
     */
    getYScaleLine(domain, height) {
        const /** @type {?} */ scale = scaleLinear()
            .range([height, 0])
            .domain(domain);
        return this.roundDomains ? scale.nice() : scale;
    }
    /**
     * @return {?}
     */
    getXScale() {
        this.xDomain = this.getXDomain();
        const /** @type {?} */ spacing = this.xDomain.length / (this.dims.width / this.barPadding + 1);
        return scaleBand()
            .rangeRound([0, this.dims.width])
            .paddingInner(spacing)
            .domain(this.xDomain);
    }
    /**
     * @return {?}
     */
    getYScale() {
        this.yDomain = this.getYDomain();
        const /** @type {?} */ scale = scaleLinear()
            .range([this.dims.height, 0])
            .domain(this.yDomain);
        return this.roundDomains ? scale.nice() : scale;
    }
    /**
     * @return {?}
     */
    getXDomain() {
        return this.results.map(d => d.name);
    }
    /**
     * @return {?}
     */
    getYDomain() {
        const /** @type {?} */ values = this.results.map(d => d.value);
        const /** @type {?} */ min = Math.min(0, ...values);
        const /** @type {?} */ max = Math.max(...values);
        if (this.yLeftAxisScaleFactor) {
            const /** @type {?} */ minMax = this.yLeftAxisScaleFactor(min, max);
            return [Math.min(0, minMax.min), minMax.max];
        }
        else {
            return [min, max];
        }
    }
    /**
     * @param {?} data
     * @return {?}
     */
    onClick(data) {
        this.select.emit(data);
    }
    /**
     * @return {?}
     */
    setColors() {
        let /** @type {?} */ domain;
        if (this.schemeType === 'ordinal') {
            domain = this.xDomain;
        }
        else {
            domain = this.yDomain;
        }
        this.customColors = this.scheme;
        this.colorSchemeLine = this.scheme;
        console.log(this.scheme, this.schemeType, domain, this.customColors, this.colorSchemeLine);
        this.colors = new ColorHelper(this.scheme, this.schemeType, domain, this.customColors);
        this.colorsLine = new ColorHelper(this.colorSchemeLine, this.schemeType, domain, this.customColors);
    }
    /**
     * @return {?}
     */
    getLegendOptions() {
        const /** @type {?} */ opts = {
            scaleType: this.schemeType,
            colors: undefined,
            domain: [],
            title: undefined
        };
        if (opts.scaleType === 'ordinal') {
            opts.domain = this.seriesDomain;
            opts.colors = this.colorsLine;
            opts.title = this.legendTitle;
        }
        else {
            opts.domain = this.seriesDomain;
            opts.colors = this.colors.scale;
        }
        return opts;
    }
    /**
     * @param {?} width
     * @return {?}
     */
    updateLineWidth(width) {
        this.bandwidth = width;
    }
    /**
     * @param {?} __0
     * @return {?}
     */
    updateYAxisWidth({ width }) {
        this.yAxisWidth = width + 20;
        this.update();
    }
    /**
     * @param {?} __0
     * @return {?}
     */
    updateXAxisHeight({ height }) {
        this.xAxisHeight = height;
        this.update();
    }
    /**
     * @param {?} item
     * @return {?}
     */
    onActivate(item) {
        const /** @type {?} */ idx = this.activeEntries.findIndex(d => {
            return d.name === item.name && d.value === item.value && d.series === item.series;
        });
        if (idx > -1) {
            return;
        }
        this.activeEntries = [item, ...this.activeEntries];
        this.activate.emit({ value: item, entries: this.activeEntries });
    }
    /**
     * @param {?} item
     * @return {?}
     */
    onDeactivate(item) {
        const /** @type {?} */ idx = this.activeEntries.findIndex(d => {
            return d.name === item.name && d.value === item.value && d.series === item.series;
        });
        this.activeEntries.splice(idx, 1);
        this.activeEntries = [...this.activeEntries];
        this.deactivate.emit({ value: item, entries: this.activeEntries });
    }
}
BarLineComponent.decorators = [
    { type: Component, args: [{
                selector: 'neu-charts-combo-bar-line-raw',
                template: `
      <ngx-charts-chart
        [view]="[width + legendSpacing, height]"
        [showLegend]="legend"
        [legendOptions]="legendOptions"
        [activeEntries]="activeEntries"
        [animations]="animations"
        (legendLabelClick)="onClick($event)"
        (legendLabelActivate)="onActivate($event)"
        (legendLabelDeactivate)="onDeactivate($event)">
        <svg:g [attr.transform]="transform" class="bar-chart chart">
            <svg:g ngx-charts-x-axis
            *ngIf="xAxis"
            [xScale]="xScale"
            [dims]="dims"
            [showLabel]="showXAxisLabel"
            [labelText]="xAxisLabel"
            [tickFormatting]="xAxisTickFormatting"
            (dimensionsChanged)="updateXAxisHeight($event)">
          </svg:g>
          <svg:g ngx-charts-y-axis
            *ngIf="yAxis"
            [yScale]="yScale"
            [dims]="dims"
            [yOrient]="yOrientLeft"
            [showGridLines]="showGridLines"
            [showLabel]="showYAxisLabel"
            [labelText]="yAxisLabel"
            [tickFormatting]="yAxisTickFormatting"
            (dimensionsChanged)="updateYAxisWidth($event)">
          </svg:g>
          <svg:g ngx-charts-y-axis
            *ngIf="yAxis"
            [yScale]="yScaleLine"
            [dims]="dims"
            [yOrient]="yOrientRight"
            [showGridLines]="showGridLines"
            [showLabel]="showRightYAxisLabel"
            [labelText]="yAxisLabelRight"
            [tickFormatting]="yRightAxisTickFormatting"
            (dimensionsChanged)="updateYAxisWidth($event)">
          </svg:g>
          <svg:g ngx-combo-charts-series-vertical
            [xScale]="xScale"
            [yScale]="yScale"
            [colors]="colors"
            [series]="results"
            [seriesLine]="lineChart"
            [dims]="dims"
            [gradient]="gradient"
            tooltipDisabled="true"
            [activeEntries]="activeEntries"
            [animations]="animations"
            (activate)="onActivate($event)"
            (deactivate)="onDeactivate($event)"
            (bandwidth)="updateLineWidth($event)"
            (select)="onClick($event)">
          </svg:g>
        </svg:g>
        <svg:g [attr.transform]="transform" class="line-chart chart">
          <svg:g [attr.clip-path]="clipPath">
            <svg:g *ngFor="let series of lineChart; trackBy:trackBy">
              <svg:g ngx-charts-line-series
                [xScale]="xScaleLine"
                [yScale]="yScaleLine"
                [colors]="colorsLine"
                [data]="series"
                [activeEntries]="activeEntries"
                [scaleType]="scaleType"
                [curve]="curve"
                [rangeFillOpacity]="rangeFillOpacity"
                [animations]="animations"
              />
            </svg:g>
            <svg:g ngx-charts-tooltip-area
              *ngIf="!tooltipDisabled"
              [dims]="dims"
              [xSet]="xSet"
              [xScale]="xScaleLine"
              [yScale]="yScaleLine"
              [results]="combinedSeries"
              [colors]="colorsLine"
              [tooltipDisabled]="tooltipDisabled"
              (hover)="updateHoveredVertical($event)"
            />
            <svg:g *ngFor="let series of lineChart">
              <svg:g ngx-charts-circle-series
                [xScale]="xScaleLine"
                [yScale]="yScaleLine"
                [colors]="colorsLine"
                [data]="series"
                [scaleType]="scaleType"
                [visibleValue]="hoveredVertical"
                [activeEntries]="activeEntries"
                [tooltipDisabled]="tooltipDisabled"
                (select)="onClick($event, series)"
                (activate)="onActivate($event)"
                (deactivate)="onDeactivate($event)"
              />
            </svg:g>
          </svg:g>
        </svg:g>
      </ngx-charts-chart>
    `,
                styles: [`.ngx-charts{float:left;overflow:visible}.ngx-charts .arc,.ngx-charts .bar,.ngx-charts .circle{cursor:pointer}.ngx-charts .arc.active,.ngx-charts .arc:hover,.ngx-charts .bar.active,.ngx-charts .bar:hover,.ngx-charts .card.active,.ngx-charts .card:hover,.ngx-charts .cell.active,.ngx-charts .cell:hover{opacity:.8;-webkit-transition:opacity .1s ease-in-out;transition:opacity .1s ease-in-out}.ngx-charts .arc:focus,.ngx-charts .bar:focus,.ngx-charts .card:focus,.ngx-charts .cell:focus,.ngx-charts g:focus{outline:0}.ngx-charts .area-series.inactive,.ngx-charts .line-series-range.inactive,.ngx-charts .line-series.inactive{-webkit-transition:opacity .1s ease-in-out;transition:opacity .1s ease-in-out;opacity:.2}.ngx-charts .line-highlight{display:none}.ngx-charts .line-highlight.active{display:block}.ngx-charts .area{opacity:.6}.ngx-charts .circle:hover{cursor:pointer}.ngx-charts .label{font-size:12px;font-weight:400}.ngx-charts .tooltip-anchor{fill:#000}.ngx-charts .gridline-path{stroke:#ddd;stroke-width:1;fill:none}.ngx-charts .grid-panel rect{fill:none}.ngx-charts .grid-panel.odd rect{fill:rgba(0,0,0,.05)}`],
                encapsulation: ViewEncapsulation.None
            },] },
];
/** @nocollapse */
BarLineComponent.ctorParameters = () => [];
BarLineComponent.propDecorators = {
    "lineSeriesComponent": [{ type: ViewChild, args: [LineSeriesComponent,] },],
    "curve": [{ type: Input },],
    "legend": [{ type: Input },],
    "legendTitle": [{ type: Input },],
    "xAxis": [{ type: Input },],
    "yAxis": [{ type: Input },],
    "showXAxisLabel": [{ type: Input },],
    "showYAxisLabel": [{ type: Input },],
    "showRightYAxisLabel": [{ type: Input },],
    "xAxisLabel": [{ type: Input },],
    "yAxisLabel": [{ type: Input },],
    "yAxisLabelRight": [{ type: Input },],
    "tooltipDisabled": [{ type: Input },],
    "gradient": [{ type: Input },],
    "showGridLines": [{ type: Input },],
    "activeEntries": [{ type: Input },],
    "schemeType": [{ type: Input },],
    "xAxisTickFormatting": [{ type: Input },],
    "yAxisTickFormatting": [{ type: Input },],
    "yRightAxisTickFormatting": [{ type: Input },],
    "roundDomains": [{ type: Input },],
    "colorSchemeLine": [{ type: Input },],
    "autoScale": [{ type: Input },],
    "lineChart": [{ type: Input },],
    "yLeftAxisScaleFactor": [{ type: Input },],
    "yRightAxisScaleFactor": [{ type: Input },],
    "rangeFillOpacity": [{ type: Input },],
    "animations": [{ type: Input },],
    "activate": [{ type: Output },],
    "deactivate": [{ type: Output },],
    "tooltipTemplate": [{ type: ContentChild, args: ['tooltipTemplate',] },],
    "seriesTooltipTemplate": [{ type: ContentChild, args: ['seriesTooltipTemplate',] },],
    "hideCircles": [{ type: HostListener, args: ['mouseleave',] },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class BarSeriesComboComponent {
    constructor() {
        this.type = 'standard';
        this.tooltipDisabled = false;
        this.animations = true;
        this.select = new EventEmitter();
        this.activate = new EventEmitter();
        this.deactivate = new EventEmitter();
        this.bandwidth = new EventEmitter();
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        this.update();
    }
    /**
     * @return {?}
     */
    update() {
        let /** @type {?} */ width;
        if (this.series.length) {
            width = this.xScale.bandwidth();
            this.bandwidth.emit(width);
        }
        let /** @type {?} */ d0 = 0;
        let /** @type {?} */ total;
        if (this.type === 'normalized') {
            total = this.series.map(d => d.value).reduce((sum, d) => sum + d, 0);
        }
        this.bars = this.series.map((d, index) => {
            let /** @type {?} */ value = d.value;
            const /** @type {?} */ label = d.name;
            const /** @type {?} */ formattedLabel = formatLabel(label);
            const /** @type {?} */ roundEdges = this.type === 'standard';
            const /** @type {?} */ bar = {
                value,
                label,
                roundEdges,
                data: d,
                width,
                formattedLabel,
                height: 0,
                x: 0,
                y: 0
            };
            if (this.type === 'standard') {
                bar.height = Math.abs(this.yScale(value) - this.yScale(0));
                bar.x = this.xScale(label);
                if (value < 0) {
                    bar.y = this.yScale(0);
                }
                else {
                    bar.y = this.yScale(value);
                }
            }
            else if (this.type === 'stacked') {
                const /** @type {?} */ offset0 = d0;
                const /** @type {?} */ offset1 = offset0 + value;
                d0 += value;
                bar.height = this.yScale(offset0) - this.yScale(offset1);
                bar.x = 0;
                bar.y = this.yScale(offset1);
                bar.offset0 = offset0;
                bar.offset1 = offset1;
            }
            else if (this.type === 'normalized') {
                let /** @type {?} */ offset0 = d0;
                let /** @type {?} */ offset1 = offset0 + value;
                d0 += value;
                if (total > 0) {
                    offset0 = (offset0 * 100) / total;
                    offset1 = (offset1 * 100) / total;
                }
                else {
                    offset0 = 0;
                    offset1 = 0;
                }
                bar.height = this.yScale(offset0) - this.yScale(offset1);
                bar.x = 0;
                bar.y = this.yScale(offset1);
                bar.offset0 = offset0;
                bar.offset1 = offset1;
                value = (offset1 - offset0).toFixed(2) + '%';
            }
            if (this.colors.scaleType === 'ordinal') {
                bar.color = this.colors.getColor(label);
            }
            else {
                if (this.type === 'standard') {
                    bar.color = this.colors.getColor(value);
                    bar.gradientStops = this.colors.getLinearGradientStops(value);
                }
                else {
                    bar.color = this.colors.getColor(bar.offset1);
                    bar.gradientStops = this.colors.getLinearGradientStops(bar.offset1, bar.offset0);
                }
            }
            let /** @type {?} */ tooltipLabel = formattedLabel;
            if (this.seriesName) {
                tooltipLabel = `${this.seriesName} • ${formattedLabel}`;
            }
            this.getSeriesTooltips(this.seriesLine, index);
            var /** @type {?} */ line = this.seriesLine[0].series[index];
            if ((this.seriesLine.length >= index) && (line)) {
                const /** @type {?} */ lineValue = line.value;
                const /** @type {?} */ lineName = line.name;
                bar.tooltipText = `
                <span class="tooltip-label">${tooltipLabel}</span>
                <span class="tooltip-val"> Y1 - ${value.toLocaleString()} • Y2 - ${lineValue.toLocaleString()}%</span>
                `;
            }
            return bar;
        });
    }
    /**
     * @param {?} seriesLine
     * @param {?} index
     * @return {?}
     */
    getSeriesTooltips(seriesLine, index) {
        return seriesLine.map(d => {
            return d.series[index];
        });
    }
    /**
     * @param {?} entry
     * @return {?}
     */
    isActive(entry) {
        if (!this.activeEntries)
            return false;
        const /** @type {?} */ item = this.activeEntries.find(d => {
            return entry.name === d.name && entry.series === d.series;
        });
        return item !== undefined;
    }
    /**
     * @param {?} data
     * @return {?}
     */
    onClick(data) {
        this.select.emit(data);
    }
    /**
     * @param {?} index
     * @param {?} bar
     * @return {?}
     */
    trackBy(index, bar) {
        return bar.label;
    }
}
BarSeriesComboComponent.decorators = [
    { type: Component, args: [{
                selector: 'g[ngx-combo-charts-series-vertical]',
                template: `
      <svg:g ngx-charts-bar *ngFor="let bar of bars; trackBy: trackBy"
        [@animationState]="'active'"
        [width]="bar.width"
        [height]="bar.height"
        [x]="bar.x"
        [y]="bar.y"
        [fill]="bar.color"
        [stops]="bar.gradientStops"
        [data]="bar.data"
        [orientation]="'vertical'"
        [roundEdges]="bar.roundEdges"
        [gradient]="gradient"
        [isActive]="isActive(bar.data)"
        [animations]="animations"
        (select)="onClick($event)"
        (activate)="activate.emit($event)"
        (deactivate)="deactivate.emit($event)"
        ngx-tooltip
        [tooltipDisabled]="tooltipDisabled"
        [tooltipPlacement]="'top'"
        [tooltipType]="'tooltip'"
        [tooltipTitle]="bar.tooltipText">
      </svg:g>
    `,
                changeDetection: ChangeDetectionStrategy.OnPush,
                animations: [
                    trigger('animationState', [
                        transition('* => void', [
                            style({
                                opacity: 1,
                                transform: '*',
                            }),
                            animate(500, style({ opacity: 0, transform: 'scale(0)' }))
                        ])
                    ])
                ]
            },] },
];
/** @nocollapse */
BarSeriesComboComponent.ctorParameters = () => [];
BarSeriesComboComponent.propDecorators = {
    "dims": [{ type: Input },],
    "type": [{ type: Input },],
    "series": [{ type: Input },],
    "seriesLine": [{ type: Input },],
    "xScale": [{ type: Input },],
    "yScale": [{ type: Input },],
    "colors": [{ type: Input },],
    "tooltipDisabled": [{ type: Input },],
    "gradient": [{ type: Input },],
    "activeEntries": [{ type: Input },],
    "seriesName": [{ type: Input },],
    "animations": [{ type: Input },],
    "select": [{ type: Output },],
    "activate": [{ type: Output },],
    "deactivate": [{ type: Output },],
    "bandwidth": [{ type: Output },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class BubbleOptions extends BarOptions {
    /**
     * @param {?=} showLegend
     * @param {?=} showXAxis
     * @param {?=} showYAxis
     * @param {?=} showXAxisLabel
     * @param {?=} showYAxisLabel
     * @param {?=} xAxisLabel
     * @param {?=} yAxisLabel
     * @param {?=} autoScale
     * @param {?=} xScaleMin
     * @param {?=} xScaleMax
     * @param {?=} yScaleMin
     * @param {?=} yScaleMax
     * @param {?=} roundDomains
     * @param {?=} minRadius
     * @param {?=} maxRadius
     * @param {?=} view
     */
    constructor(showLegend = true, showXAxis = true, showYAxis = true, showXAxisLabel = true, showYAxisLabel = true, xAxisLabel = 'x', yAxisLabel = 'y', autoScale = true, xScaleMin = 0, xScaleMax = 20, yScaleMin = 0, yScaleMax = 0, roundDomains = true, minRadius = 4, maxRadius = 15, view = undefined) {
        super(showLegend, showXAxis, showYAxis, showXAxisLabel, showYAxisLabel, xAxisLabel, yAxisLabel);
        this.view = view;
        this.autoScale = autoScale;
        this.xScaleMin = xScaleMin;
        this.xScaleMax = xScaleMax;
        this.yScaleMin = yScaleMin;
        this.yScaleMax = yScaleMax;
        this.roundDomains = roundDomains;
        this.minRadius = minRadius;
        this.maxRadius = maxRadius;
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class BubbleComponent {
    constructor() {
        this.data = [];
        this.onSelect = new EventEmitter();
        this.options = new BubbleOptions();
        this.colorScheme = customColorSets.find(s => s.name == 'palatte');
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        Object.assign(this.options, this.customOptions);
        console.log("bub option", this.options);
    }
    /**
     * @param {?} event
     * @return {?}
     */
    mSelectedEvent(event) {
        this.onSelect.emit(event);
    }
}
BubbleComponent.decorators = [
    { type: Component, args: [{
                selector: 'neu-charts-bubble',
                template: `<div class="chart-container" *ngIf="data && (data.length > 0)">
    <ngx-charts-bubble-chart
        [view]="options.view"
        [scheme]="colorScheme"
        [results]="data"
        [legend]="options.showLegend"
        [xAxis]="options.showXAxis"
        [yAxis]="options.showYAxis"
        [showXAxisLabel]="options.showXAxisLabel"
        [showYAxisLabel]="options.showYAxisLabel"
        [xAxisLabel]="options.xAxisLabel"
        [yAxisLabel]="options.yAxisLabel"
        [autoScale]="options.autoScale"
        [roundDomains]="options.roundDomains"
        [minRadius]="options.minRadius"
        [maxRadius]="options.maxRadius"
        (select)="mSelectedEvent($event)">
    </ngx-charts-bubble-chart>
</div>
<no-data *ngIf="(!data) || (data.length <= 0)"></no-data>`,
                styles: [``]
            },] },
];
/** @nocollapse */
BubbleComponent.ctorParameters = () => [];
BubbleComponent.propDecorators = {
    "data": [{ type: Input, args: ['data',] },],
    "customOptions": [{ type: Input, args: ['options',] },],
    "onSelect": [{ type: Output },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class DirectedGraph {
    /**
     * @param {?=} view
     * @param {?=} showLegend
     * @param {?=} orientation
     * @param {?=} autoCenter
     * @param {?=} autoZoom
     */
    constructor(view = [], showLegend = false, orientation = 'TB', autoCenter = true, autoZoom = true) {
        this.view = view;
        this.showLegend = showLegend;
        this.orientation = orientation;
        this.autoCenter = autoCenter;
        this.autoZoom = autoZoom;
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class DirectedGraphComponent {
    constructor() {
        this.options = new DirectedGraph;
        this.curve = curveBundle;
        this.colorScheme = customColorSets.find(s => s.name == 'palatte');
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        Object.assign(this.options, this.customOptions);
    }
    /**
     * @param {?} event
     * @return {?}
     */
    mOnSelect(event) {
        console.log('clicked', event);
    }
}
DirectedGraphComponent.decorators = [
    { type: Component, args: [{
                selector: 'neu-directed-graph',
                template: `<div *ngIf="data && data['links'] && data['nodes']" class="chart-container">
    <ngx-graph class="chart-container"
        [links]="data['links']"
        [nodes]="data['nodes']"
        [scheme]="colorScheme"
        [view]="options.view"
        [legend]="options.showLegend"
        [orientation]="options.orientation"
        [curve]="curve"
        [autoCenter]="options.autoCenter"
        [autoZoom]="options.autoZoom"
        (select)="mOnSelect($event)">
        <ng-template #defsTemplate>
            <svg:marker id="arrow" viewBox="0 -5 10 10" refX="8" refY="0" markerWidth="4" markerHeight="4" orient="auto">
                <svg:path d="M0,-5L10,0L0,5" class="arrow-head" />
            </svg:marker>
        </ng-template>
        <ng-template #nodeTemplate let-node>
            <svg:g class="node">
                <!-- ngx-tooltip [tooltipPlacement]="'top'" [tooltipType]="'tooltip'" [tooltipTitle]="node.label"> -->
                <svg:rect [attr.width]="node.width" [attr.height]="node.height" [attr.fill]="node.options.color" />
                <svg:text alignment-baseline="central" [attr.x]="10" [attr.y]="node.height / 2">{{node.label}}</svg:text>
            </svg:g>
        </ng-template>
        <ng-template #linkTemplate let-link>
            <svg:g class="edge">
                <svg:path
                    class="line"
                    stroke-width="2"
                    marker-end="url(#arrow)">
                </svg:path>
                <svg:text class="edge-label" text-anchor="middle">
                    <textPath class="text-path"
                        style="fill: #666;"
                        [attr.href]="'#' + link.id"
                        [style.dominant-baseline]="link.dominantBaseline"
                        startOffset="50%">
                        {{link.label}}
                    </textPath>
                </svg:text>
            </svg:g>
        </ng-template>
    </ngx-graph>
</div>
<no-data *ngIf="(!data) || (!data['links']) || (!data['nodes'])"></no-data>`,
                styles: [``]
            },] },
];
/** @nocollapse */
DirectedGraphComponent.ctorParameters = () => [];
DirectedGraphComponent.propDecorators = {
    "data": [{ type: Input },],
    "customOptions": [{ type: Input, args: ['options',] },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
let PIECOMPONENTS = [PieChartComponent, DonutChartComponent, DonutAdvancedComponent, DonutGridComponent];
let BARCOMPONENTS = [BarVerticalComponent, BarHorizontalComponent, BarVerticalGroupedComponent, BarHorizontalGroupedComponent,
    BarHorizontalStackedComponent, BarVerticalStackedComponent, BarVerticalNormalizedComponent, BarHorizontalNormalizedComponent];
let LINEORAREACOMPONENTS = [LineComponent, AreaComponent, AreaStackedComponent, AreaNormalizedComponent];
let MAPCOMPONENTS = [HeatComponent, TreeComponent];
let COMBOCOMPONENT = [BarLineWrapperComponent, BarLineComponent, BarSeriesComboComponent];
let SCATTERCOMPONENT = [BubbleComponent];
let GRAPHCOMPONENT = [DirectedGraphComponent];
class NeuChartsModule {
}
NeuChartsModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    NgxChartsModule,
                    NgxGraphModule
                ],
                declarations: [NeuChartsComponent, NoDataComponent,
                    ...PIECOMPONENTS,
                    ...BARCOMPONENTS,
                    ...LINEORAREACOMPONENTS,
                    ...MAPCOMPONENTS,
                    ...COMBOCOMPONENT,
                    ...SCATTERCOMPONENT,
                    ...GRAPHCOMPONENT
                ],
                exports: [
                    ...PIECOMPONENTS,
                    ...BARCOMPONENTS,
                    ...LINEORAREACOMPONENTS,
                    ...MAPCOMPONENTS,
                    ...COMBOCOMPONENT,
                    ...SCATTERCOMPONENT,
                    ...GRAPHCOMPONENT
                ]
            },] },
];
/** @nocollapse */
NeuChartsModule.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Generated bundle index. Do not edit.
 */

export { NeuChartsModule, BarHorizontalGroupedComponent as ɵj, BarHorizontalNormalizedComponent as ɵn, BarHorizontalStackedComponent as ɵk, BarHorizontalComponent as ɵh, BarVerticalGroupedComponent as ɵi, BarVerticalNormalizedComponent as ɵm, BarVerticalStackedComponent as ɵl, BarVerticalComponent as ɵg, BarLineWrapperComponent as ɵu, BarLineComponent as ɵv, BarSeriesComboComponent as ɵw, DirectedGraphComponent as ɵy, AreaNormalizedComponent as ɵr, AreaStackedComponent as ɵq, AreaComponent as ɵp, LineComponent as ɵo, HeatComponent as ɵs, TreeComponent as ɵt, DonutAdvancedComponent as ɵe, DonutChartComponent as ɵd, DonutGridComponent as ɵf, PieChartComponent as ɵc, BubbleComponent as ɵx, NeuChartsComponent as ɵa, NoDataComponent as ɵb };
//# sourceMappingURL=neu-charts.js.map
